<?php

namespace Drupal\doghouse_menu\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'MenuToggle' block.
 *
 * @Block(
 *  id = "doghouse_menu_toggle",
 *  admin_label = @Translation("Doghouse Menu Toggle"),
 * )
 */
class MenuToggle extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
        'toggle_text' => 'Menu Toggle',
        'toggle_animation' => 'slide_l',
      ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['toggle_text'] = [
      '#type' => 'textfield',
      '#title' => 'Toggle Button Text',
      '#description' => $this->t('The text to display in the toggle button'),
      '#default_value' => $this->configuration['toggle_text'],
      '#required' => TRUE,
    ];

    $form['toggle_animation'] = [
      '#type' => 'select',
      '#title' => $this->t('Toggle Animatopm'),
      '#description' => $this->t("Select how you want the <em>Doghouse Menu</em> region to appear."),
      '#default_value' => $this->configuration['toggle_animation'],
      '#options' => [
        'slide_l' => $this->t('Slide in left'),
        'slide_r' => $this->t('Slide in right'),
        'slide_t' => $this->t('Slide in top'),
        'slide_b' => $this->t('Slide in bottom'),
        'fade' => $this->t('Fade'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['toggle_text'] = $form_state->getValue('toggle_text');
    $this->configuration['toggle_animation'] = $form_state->getValue('toggle_animation');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [
      '#attributes' => [
        'class' => ['doghouse-menu-toggle'],
      ],
      '#attached' => [
        'library' => [
          'doghouse_menu/doghouse_menu_toggle',
        ],
      ],
    ];
    $build['menu_toggle'] = [
      '#theme' => 'doghouse_menu_toggle',
      '#text' => $this->configuration['toggle_text'],
      '#toggle_animation' => $this->configuration['toggle_animation'],
    ];

    return $build;
  }

}
